Interface: GridLineOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: GridLineOptions

## # Properties

### # borderColor

• borderColor: `Color`

#### # Defined in

index.esm.d.ts:2853
(opens new window)

### # borderDash

• borderDash: `Scriptable`<`number`[], `ScriptableScaleContext`>

`default` []

#### # Defined in

index.esm.d.ts:2866
(opens new window)

### # borderDashOffset

• borderDashOffset: `Scriptable`<`number`, `ScriptableScaleContext`>

`default` 0

#### # Defined in

index.esm.d.ts:2870
(opens new window)

### # borderWidth

• borderWidth: `number`

#### # Defined in

index.esm.d.ts:2854
(opens new window)

### # circular

• circular: `boolean`

`default` false

#### # Defined in

index.esm.d.ts:2858
(opens new window)

### # color

• color: `ScriptableAndArray`<`Color`, `ScriptableScaleContext`>

`default` 'rgba(0, 0, 0, 0.1)'

#### # Defined in

index.esm.d.ts:2862
(opens new window)

### # display

• display: `boolean`

`default` true

#### # Defined in

index.esm.d.ts:2852
(opens new window)

### # drawBorder

• drawBorder: `boolean`

`default` true

#### # Defined in

index.esm.d.ts:2879
(opens new window)

### # drawOnChartArea

• drawOnChartArea: `boolean`

`default` true

#### # Defined in

index.esm.d.ts:2883
(opens new window)

### # drawTicks

• drawTicks: `boolean`

`default` true

#### # Defined in

index.esm.d.ts:2887
(opens new window)

### # lineWidth

• lineWidth: `ScriptableAndArray`<`number`, `ScriptableScaleContext`>

`default` 1

#### # Defined in

index.esm.d.ts:2874
(opens new window)

### # offset

• offset: `boolean`

`default` false

#### # Defined in

index.esm.d.ts:2911
(opens new window)

### # tickBorderDash

• tickBorderDash: `number`[]

`default` []

#### # Defined in

index.esm.d.ts:2891
(opens new window)

### # tickBorderDashOffset

• tickBorderDashOffset: `Scriptable`<`number`, `ScriptableScaleContext`>

`default` 0

#### # Defined in

index.esm.d.ts:2895
(opens new window)

### # tickColor

• tickColor: `ScriptableAndArray`<`Color`, `ScriptableScaleContext`>

`default` 'rgba(0, 0, 0, 0.1)'

#### # Defined in

index.esm.d.ts:2899
(opens new window)

### # tickLength

• tickLength: `number`

`default` 10

#### # Defined in

index.esm.d.ts:2903
(opens new window)

### # tickWidth

• tickWidth: `number`

`default` 1

#### # Defined in

index.esm.d.ts:2907
(opens new window)

### # z

• z: `number`

`default` 0

#### # Defined in

index.esm.d.ts:2915
(opens new window)